BitCaptchaTextChallenge class
A text / icon click challenge: a background plus ordered targets. Positions stay on the server; the client only gets targets and canvas size.
Constructors
-
BitCaptchaTextChallenge({required String token, required Uint8List bg, required double width, required double height, required List<
String> targets, required List<Uint8List> icons, required int count, required bool enhanced, required int expiresIn}) -
BitCaptchaTextChallenge.fromJson(Map<
String, dynamic> j) -
factory
Properties
- bg → Uint8List
-
final
- count → int
-
final
- enhanced → bool
-
final
- expiresIn → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
-
icons
→ List<
Uint8List> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targets
→ List<
String> -
final
- token → String
-
final
- width → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited